@@ -28,6 +28,7 @@
 #include "latexila-build-job.h"
 #include <string.h>
 #include <glib/gi18n.h>
+#include <tepl/tepl.h>
 #include "latexila-build-view.h"
 #include "latexila-post-processor-all-output.h"
 #include "latexila-post-processor-latex.h"
@@ -271,7 +272,7 @@ get_command_argv (GTask     *task,
 
 	/* Replace placeholders */
 	base_filename = g_file_get_basename (data->file);
-	base_shortname = latexila_utils_get_shortname (base_filename);
+	base_shortname = tepl_utils_get_file_shortname (base_filename);
 
 	for (i = 0; argv[i] != NULL; i++)
 	{
@@ -279,16 +280,16 @@ get_command_argv (GTask     *task,
 
 		if (strstr (argv[i], "$filename") != NULL)
 		{
-			new_arg = latexila_utils_str_replace (argv[i], "$filename", base_filename);
+			new_arg = tepl_utils_str_replace (argv[i], "$filename", base_filename);
 		}
 		else if (strstr (argv[i], "$shortname"))
 		{
-			new_arg = latexila_utils_str_replace (argv[i], "$shortname", base_shortname);
+			new_arg = tepl_utils_str_replace (argv[i], "$shortname", base_shortname);
 		}
 		else if (strstr (argv[i], "$view"))
 		{
 			g_warning ("Build job: the '$view' placeholder is deprecated.");
-			new_arg = latexila_utils_str_replace (argv[i], "$view", "xdg-open");
+			new_arg = tepl_utils_str_replace (argv[i], "$view", "xdg-open");
 		}
 
 		if (new_arg != NULL)
