@@ -1,7 +1,7 @@
 /*
  * This file is part of GNOME LaTeX.
  *
- * Copyright (C) 2014 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014-2022 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GNOME LaTeX is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,9 +33,9 @@
  * tools can not be modified and are not saved to another XML file.
  */
 
-#include "config.h"
 #include "latexila-build-tools-default.h"
 #include <gio/gio.h>
+#include "latexila-dirs.h"
 
 struct _LatexilaBuildToolsDefaultPrivate
 {
@@ -178,7 +178,7 @@ get_xml_file (void)
 	gchar *path;
 	GFile *file;
 
-	path = g_build_filename (DATA_DIR, "build_tools.xml", NULL);
+	path = g_build_filename (latexila_dirs_get_app_data_dir (), "build_tools.xml", NULL);
 	file = g_file_new_for_path (path);
 	g_free (path);
 
