@@ -241,7 +241,8 @@ fetch_sub_title (LatexilaPostProcessorLatexmk *pp,
 		rule = g_match_info_fetch_named (match_info, "rule");
 
 		pp->priv->last_rule_is_latex_rule = (g_strcmp0 (rule, "latex") == 0 ||
-						     g_strcmp0 (rule, "pdflatex") == 0);
+						     g_strcmp0 (rule, "pdflatex") == 0 ||
+						     g_strcmp0 (rule, "xelatex") == 0);
 
 		if (pp->priv->last_rule_is_latex_rule)
 		{
