@@ -1,7 +1,7 @@
 /*
  * This file is part of GNOME LaTeX.
  *
- * Copyright (C) 2015 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2015-2022 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GNOME LaTeX is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,9 +43,9 @@
  * that is more suitable for the target language.
  */
 
-#include "config.h"
 #include "latexila-templates-default.h"
 #include <glib/gi18n.h>
+#include "latexila-dirs.h"
 #include "latexila-templates-common.h"
 
 struct _LatexilaTemplatesDefault
@@ -69,7 +69,7 @@ add_default_template (LatexilaTemplatesDefault *templates,
 	gchar *path;
 	GFile *file;
 
-	path = g_build_filename (DATA_DIR, "templates", filename, NULL);
+	path = g_build_filename (latexila_dirs_get_app_data_dir (), "templates", filename, NULL);
 	file = g_file_new_for_path (path);
 
 	latexila_templates_add_template (GTK_LIST_STORE (templates),
