@@ -335,7 +335,10 @@ latexila_templates_manage_dialog_init (LatexilaTemplatesManageDialog *manage_dia
 
 	toolbar = init_toolbar (manage_dialog);
 
-	dialog_content = latexila_utils_join_widgets (scrolled_window, GTK_WIDGET (toolbar));
+	dialog_content = gtk_grid_new ();
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (dialog_content), GTK_ORIENTATION_VERTICAL);
+	gtk_container_add (GTK_CONTAINER (dialog_content), scrolled_window);
+	gtk_container_add (GTK_CONTAINER (dialog_content), GTK_WIDGET (toolbar));
 
 	content_area = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (manage_dialog)));
 	gtk_box_pack_start (content_area, dialog_content, TRUE, TRUE, 0);
