@@ -6,7 +6,7 @@
  * Copyright (C) 2000, 2002 - Chema Celorio, Paolo Maggi
  * Copyright (C) 2003-2005 - Paolo Maggi
  *
- * Copyright (C) 2014-2020 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014-2022 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GNOME LaTeX is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,53 +40,6 @@
 #include "dh-dconf-migration.h"
 #endif
 
-/**
- * latexila_utils_register_icons:
- *
- * Register the GNOME LaTeX icons to the #GtkIconTheme as built-in icons.
- *
- * TODO: prefix icon names with "glatex-", so for example badbox.png would be
- * "glatex-badbox".
- */
-void
-latexila_utils_register_icons (void)
-{
-	gtk_icon_theme_add_resource_path (gtk_icon_theme_get_default (),
-					  "/org/gnome/gnome-latex/stock-icons/");
-}
-
-/**
- * latexila_utils_get_pixbuf_from_icon_name:
- * @icon_name: an icon name.
- * @icon_size: an icon size.
- *
- * Returns: (nullable) (transfer full): the corresponding #GdkPixbuf.
- */
-GdkPixbuf *
-latexila_utils_get_pixbuf_from_icon_name (const gchar *icon_name,
-					  GtkIconSize  icon_size)
-{
-	gint size;
-	GdkPixbuf *pixbuf;
-	GError *error = NULL;
-
-	gtk_icon_size_lookup (icon_size, &size, NULL);
-
-	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					   icon_name,
-					   size,
-					   0,
-					   &error);
-
-	if (error != NULL)
-	{
-		g_warning ("Error when loading icon \"%s\": %s", icon_name, error->message);
-		g_error_free (error);
-	}
-
-	return pixbuf;
-}
-
 static gboolean
 default_document_viewer_is_evince (const gchar *uri)
 {
@@ -171,10 +124,10 @@ latexila_utils_show_uri (GtkWidget    *widget,
  * @title: the title of the dialog component.
  * @widget: the widget displayed below the title.
  *
- * Gets a #GtkDialog component. When a dialog contains several components, or
- * logical groups, this function is useful to attach the @widget with a @title.
- * The title will be in bold, left-aligned, and the widget will have a left
- * margin.
+ * Like tepl_utils_get_titled_component() but with an additional overall margin
+ * on all sides.
+ *
+ * TODO: migrate everything to tepl_utils_get_titled_component().
  *
  * Returns: (transfer floating): the dialog component containing the @title and
  * the @widget.
@@ -183,65 +136,18 @@ GtkWidget *
 latexila_utils_get_dialog_component (const gchar *title,
 				     GtkWidget   *widget)
 {
-	GtkContainer *grid;
-	GtkWidget *label;
-	gchar *markup;
+	GtkWidget *titled_component;
 
-	grid = GTK_CONTAINER (gtk_grid_new ());
-	gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
-	gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
-	gtk_container_set_border_width (grid, 6);
+	g_return_val_if_fail (title != NULL, NULL);
+	g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);
 
-	/* Title in bold, left-aligned. */
-	label = gtk_label_new (NULL);
-	markup = g_strdup_printf ("<b>%s</b>", title);
-	gtk_label_set_markup (GTK_LABEL (label), markup);
-	gtk_widget_set_halign (label, GTK_ALIGN_START);
-	gtk_container_add (grid, label);
+	titled_component = tepl_utils_get_titled_component (title, widget);
 
-	/* Left margin for the widget. */
-	gtk_widget_set_margin_start (widget, 12);
-	gtk_container_add (grid, widget);
+	g_object_set (titled_component,
+		      "margin", 6,
+		      NULL);
 
-	g_free (markup);
-	return GTK_WIDGET (grid);
-}
-
-/**
- * latexila_utils_join_widgets:
- * @widget_top: the #GtkWidget at the top.
- * @widget_bottom: the #GtkWidget at the bottom.
- *
- * Joins two widgets vertically, with junction sides.
- *
- * Returns: (transfer floating): a #GtkContainer containing @widget_top and
- * @widget_bottom.
- */
-/* TODO try to simply add the GTK_STYLE_CLASS_LINKED class to the
- * GtkStyleContext of a GtkBox. Test also in RTL (right-to-left) text, although
- * here it's a vertical container so it should not matter.
- */
-GtkWidget *
-latexila_utils_join_widgets (GtkWidget *widget_top,
-			     GtkWidget *widget_bottom)
-{
-	GtkStyleContext *context;
-	GtkBox *vbox;
-
-	g_return_val_if_fail (GTK_IS_WIDGET (widget_top), NULL);
-	g_return_val_if_fail (GTK_IS_WIDGET (widget_bottom), NULL);
-
-	context = gtk_widget_get_style_context (widget_top);
-	gtk_style_context_set_junction_sides (context, GTK_JUNCTION_BOTTOM);
-
-	context = gtk_widget_get_style_context (widget_bottom);
-	gtk_style_context_set_junction_sides (context, GTK_JUNCTION_TOP);
-
-	vbox = GTK_BOX (gtk_box_new (GTK_ORIENTATION_VERTICAL, 0));
-	gtk_box_pack_start (vbox, widget_top, TRUE, TRUE, 0);
-	gtk_box_pack_start (vbox, widget_bottom, FALSE, FALSE, 0);
-
-	return GTK_WIDGET (vbox);
+	return titled_component;
 }
 
 static void
