@@ -1,7 +1,7 @@
 /*
  * This file is part of GNOME LaTeX.
  *
- * Copyright (C) 2014-2015, 2018 - Sébastien Wilmet <swilmet@gnome.org>
+ * Copyright (C) 2014-2022 - Sébastien Wilmet <swilmet@gnome.org>
  *
  * GNOME LaTeX is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,28 +24,14 @@
 
 G_BEGIN_DECLS
 
-/* File utilities */
-
 void		latexila_utils_show_uri				(GtkWidget    *widget,
 								 const gchar  *uri,
 								 guint32       timestamp,
 								 GError      **error);
 
-/* UI utilities */
-
 GtkWidget *	latexila_utils_get_dialog_component		(const gchar *title,
 								 GtkWidget   *widget);
 
-GtkWidget *	latexila_utils_join_widgets			(GtkWidget *widget_top,
-								 GtkWidget *widget_bottom);
-
-GdkPixbuf *	latexila_utils_get_pixbuf_from_icon_name	(const gchar *icon_name,
-								 GtkIconSize  icon_size);
-
-/* Others */
-
-void		latexila_utils_register_icons			(void);
-
 void		latexila_utils_migrate_latexila_to_gnome_latex	(void);
 
 G_END_DECLS
